import { FC, HTMLAttributes, ReactChild } from 'react';
export interface SectionProps extends HTMLAttributes<HTMLElement> {
    /**
     * Classi aggiuntive da usare per il contenitore più esterno
     * Per replicare il comportamento precedente, in cui `className` veniva applicato anche al wrapper,
     * passare `true`.
     * */
    wrapperClassName?: string | true;
    /** Classi aggiuntive da usare per il contenitore più interno */
    className?: string;
    /**
     * Colore utilizzato per lo sfondo del componente Section.
     * In caso di `primary` o `neutral` si consiglia di applicare la classe `.white-color` al contenuto per garantire la leggibilità dei testi.
     * */
    color?: 'primary' | 'neutral' | 'muted' | string;
    /**
     * Indicare l'URL dell'immagine da utilizzare come sfondo della sezione.
     */
    image?: string;
    /** Il contenuto della sezione */
    children?: ReactChild | ReactChild[];
    /** Quando abilitato applica lo sfondo di tipo "neutral" al componente.
     * @deprecated. Utilizzare `color="neutral"`
     */
    neutral?: boolean;
    /** Quando abilitato applica lo sfondo di tipo "muted" al componente.
     * @deprecated. Utilizzare `color="muted"`
     */
    muted?: boolean;
}
export declare const Section: FC<SectionProps>;
